﻿using System;
using System.Collections;
using System.Collections.Generic;
using System.IO;
using System.Linq;
using System.Runtime.InteropServices;
using System.Security.Cryptography;
using System.Text;
using System.Xml;
using UnityEngine;

public class ScoreoidManager : SingletonMonoBehaviour<ScoreoidManager>
{
    [SerializeField] private string scoreoidApiKey;
    [SerializeField] private string scoreoidGameId;
    [SerializeField] private bool useAdvancedSecurity;
    [SerializeField] private string securityKey;

    public delegate void StatusCallback(bool success, string result, string error);

    private WWWForm CreateForm(params string[] fields)
    {
        var form = new WWWForm();
        //form.AddField("api_key", scoreoidApiKey);
        form.AddField("game_id", scoreoidGameId);

        if (useAdvancedSecurity)
        {
            string fieldString = "api_key=" + scoreoidApiKey;
            for (int i = 0; i < fields.Length; i += 2)
            {
                fieldString += String.Format("&{0}={1}", fields[i], fields[i + 1]);
            }
            Debug.Log(fieldString);

            form.AddField("s", Encrypt(fieldString));
        }
        else
        {
            form.AddField("api_key", scoreoidApiKey);
            for (int i = 0; i < fields.Length; i += 2)
            {
                form.AddField(fields[i], fields[i + 1]);
            }
        }

        return form;
    }

    public void SendRequest(string action, StatusCallback callback, params string[] fields)
    {
        //var url = "https://www.scoreoid.com/api/" + action + URLUniqueReloadPostfix;
        var url = "https://www.scoreoid.com/api/" + action;
        //var url = "https://api.scoreoid.com/v1/" + action;
        var www = new WWW(url, CreateForm(fields));
        StartCoroutine(WaitForRequest(www, url, callback));
    }

    private IEnumerator WaitForRequest(WWW www, string url, StatusCallback callback)
    {
        yield return www;

        /* Check for errors */
        if (www.error == null)
        {
            // TODO deal with errors here

            var result = www.text;
            if (useAdvancedSecurity)
                result = Decrypt(result);

            if (callback != null)
                callback(true, result, null);
        }
        else
        {
            Debug.Log(url + " WWW Error: " + www.error);
            if (callback != null)
                callback(false, null, www.error);
        }
    }

    public string URLUniqueReloadPostfix
    {
        get { return "?reload=" + DateTime.Now.Ticks; }
    }

    public string Decrypt(string encryptedString)
    {
        DESCryptoServiceProvider desProvider = new DESCryptoServiceProvider();
        desProvider.Mode = CipherMode.ECB;
        desProvider.Padding = PaddingMode.PKCS7;
        desProvider.Key = Encoding.ASCII.GetBytes(securityKey);
        using (MemoryStream stream = new MemoryStream(Convert.FromBase64String(encryptedString)))
        {
            using (CryptoStream cs = new CryptoStream(stream, desProvider.CreateDecryptor(), CryptoStreamMode.Read))
            {
                using (StreamReader sr = new StreamReader(cs, Encoding.ASCII))
                {
                    return sr.ReadToEnd();
                }
            }
        }
    }

    public string Encrypt(string decryptedString)
    {
        DESCryptoServiceProvider desProvider = new DESCryptoServiceProvider();
        desProvider.Mode = CipherMode.ECB;
        desProvider.Padding = PaddingMode.PKCS7;
        desProvider.Key = Encoding.ASCII.GetBytes(securityKey);
        using (MemoryStream stream = new MemoryStream())
        {
            using (CryptoStream cs = new CryptoStream(stream, desProvider.CreateEncryptor(), CryptoStreamMode.Write))
            {
                byte[] data = Encoding.Default.GetBytes(decryptedString);
                cs.Write(data, 0, data.Length);
                cs.FlushFinalBlock(); // <-- Add this
                return Convert.ToBase64String(stream.ToArray());
            }
        }
    }
}
