﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using UnityEngine;

public class GuiVanishingText
{
    private string text;
    private Vector2 position;
    private Vector2 relativeAnchor;
    private Color color;
    private Font font;
    private float fontSize;
    private TextAlignment alignment;

    private float timeLeft;
    private float vanishStartTime;
    private float startAlpha;

    private bool outline;
    private int outlineStrength;
    private Color outlineColor;

    public GuiVanishingText(string text, Vector2 position, Vector2 relativeAnchor, Color color, Font font, float fontSize, float timeTillVanish, float vanishTime, TextAlignment alignment = TextAlignment.Left)
    {
        this.text = text;
        this.position = position;
        this.relativeAnchor = relativeAnchor;

        this.color = color;
        this.font = font;
        this.fontSize = fontSize;
        startAlpha = color.a;

        this.alignment = alignment;

        timeLeft = timeTillVanish + vanishTime;
        vanishStartTime = vanishTime;

        Vanished = false;
    }

    public GuiVanishingText(string text, Vector2 position, Vector2 relativeAnchor, Color color, int outlineStrength, Color outlineColor, Font font, float fontSize, float timeTillVanish, float vanishTime, TextAlignment alignment = TextAlignment.Left)
        : this(text, position, relativeAnchor, color, font, fontSize, timeTillVanish, vanishTime, alignment)
    {
        this.outlineStrength = outlineStrength;
        this.outlineColor = outlineColor;
        outline = true;
    }

    public void Update()
    {
        timeLeft -= Time.smoothDeltaTime;
        if (timeLeft < 0)
        {
            Vanished = true;
        }
        else if (timeLeft < vanishStartTime)
        {
            color.a = (timeLeft / vanishStartTime) * startAlpha;
            outlineColor.a = color.a;
        }
    }

    public void Draw()
    {
        UnityHelper.SetFont(font, fontSize);

        if (outline)
        {
            UnityHelper.ShowTextOutlined(text, position, relativeAnchor, color, outlineStrength, outlineColor, alignment, false, true);
        }
        else
        {
            UnityHelper.ShowText(text, position, relativeAnchor, color, alignment, false, true);
        }
    }

    public bool Vanished { get; private set; }
}
