﻿using System;
using System.Collections;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using UnityEngine;

public class IntroductionText : MonoBehaviour
{
    [SerializeField] private float showTimeDelay = 4f;
    [SerializeField] private float fadeTime = 1f;
    [SerializeField] private float fullAlpha = 1f;

    private bool visible;

    public string Text
    {
        get { return GetComponent<TextMesh>().text; }
        set { GetComponent<TextMesh>().text = value; }
    }

    public bool Showing
    {
        get { return gameObject.activeInHierarchy && visible; }
    }

    public void Show()
    {
        StartCoroutine(ShowText());
    }

    public void Hide()
    {
        StartCoroutine(HideText());
    }

    private IEnumerator ShowText()
    {
        visible = true;

        var color = renderer.material.color;
        color.a = 0;
        renderer.material.color = color;

        yield return new WaitForSeconds(showTimeDelay);

        var countdown = new Countdown(fadeTime);

        while (!countdown.Update(UnityHelper.RealDeltaTime))
        {
            color.a = countdown.Percent * fullAlpha;
            renderer.material.color = color;
            yield return null;
        }

        color.a = fullAlpha;
        renderer.material.color = color;
    }

    private IEnumerator HideText()
    {
        visible = false;

        var countdown = new Countdown(fadeTime);

        var color = renderer.material.color;
        while (!countdown.Update(UnityHelper.RealDeltaTime))
        {
            color.a = (1 - countdown.Percent) * fullAlpha;
            renderer.material.color = color;
            yield return null;
        }

        color.a = 0;
        renderer.material.color = color;
    }
}
