﻿using System;
using System.Collections.Generic;
using UnityEngine;

public class ChooseGamepadInput : SingletonMonoBehaviour<ChooseGamepadInput>
{
    [SerializeField] private GamepadInput[] windowsNativePrefabs;
    [SerializeField] private GamepadInput[] osxPrefabs;
    [SerializeField] private GamepadInput[] defaultInputPrefabs;
    [SerializeField] private GamepadInput[] sharedInputPrefabs;
    [SerializeField] private GamepadInput[] debugInputPrefabs;

    public GamepadInput GamepadInput { get; set; }

    private void Awake()
    {
        var prefabs = new List<GamepadInput>();

        switch (Application.platform)
        {
            case RuntimePlatform.OSXEditor:
            case RuntimePlatform.OSXPlayer:
            case RuntimePlatform.OSXDashboardPlayer:
            case RuntimePlatform.OSXWebPlayer:
                prefabs.AddRange(osxPrefabs);
                break;

            case RuntimePlatform.WindowsEditor:
            case RuntimePlatform.WindowsPlayer:
                prefabs.AddRange(windowsNativePrefabs);
                break;
        }

        if (prefabs.Count == 0)
            prefabs.AddRange(defaultInputPrefabs);

        prefabs.AddRange(sharedInputPrefabs);

        var inputs = new List<GamepadInput>();

        foreach (var inputPrefab in prefabs)
        {
            var normalInputGameObject = (GameObject) Instantiate(inputPrefab.gameObject);
            inputs.Add(normalInputGameObject.GetComponent<GamepadInput>());
        }

        if (Debug.isDebugBuild)
        {
            foreach (var inputPrefab in debugInputPrefabs)
            {
                var normalInputGameObject = (GameObject) Instantiate(inputPrefab.gameObject);
                inputs.Add(normalInputGameObject.GetComponent<GamepadInput>());
            }
        }

        if (inputs.Count == 1)
        {
            GamepadInput = inputs[0];
        }
        else
        {
            var mixer = gameObject.AddComponent<GamepadInputMixer>();
            mixer.Initialize(inputs.ToArray());
            GamepadInput = mixer;
        }
    }
}
