﻿using System.Collections.Generic;
using System.Linq;

public class GamepadInputMixer : GamepadInput
{
    private List<GamepadInput> gamepadInputs;

    public void Initialize(params GamepadInput[] gamepadInputs)
    {
        this.gamepadInputs = gamepadInputs.ToList();
    }

    public void Add(GamepadInput gamepadInput)
    {
        gamepadInputs.Add(gamepadInput);
    }

    public override bool GetButton(int gamepadIndex, Button button)
    {
        return gamepadInputs.Any(gamepadInput => gamepadInput.GetButton(gamepadIndex, button));
    }

    public override bool GetButtonDown(int gamepadIndex, Button button)
    {
        return gamepadInputs.Any(gamepadInput => gamepadInput.GetButtonDown(gamepadIndex, button));
    }

    public override bool GetButtonUp(int gamepadIndex, Button button)
    {
        return gamepadInputs.Any(gamepadInput => gamepadInput.GetButtonUp(gamepadIndex, button));
    }

    public override bool GetButton(Button button)
    {
        return gamepadInputs.Any(gamepadInput => gamepadInput.GetButton(button));
    }

    public override bool GetButtonDown(Button button)
    {
        return gamepadInputs.Any(gamepadInput => gamepadInput.GetButtonDown(button));
    }

    public override bool GetButtonUp(Button button)
    {
        return gamepadInputs.Any(gamepadInput => gamepadInput.GetButtonUp(button));
    }

    public override float GetAxis(int gamepadIndex, Axis axis)
    {
        return gamepadInputs.Select(gamepadInput => gamepadInput.GetAxis(gamepadIndex, axis)).FirstOrDefault(result => result != 0f);
    }

    public override void SetLowestVibrationThisFrame(int gamepadIndex, float left, float right)
    {
        foreach (var gamepadInput in gamepadInputs)
            gamepadInput.SetLowestVibrationThisFrame(gamepadIndex, left, right);
    }
}
