using System.Linq;
using UnityEngine;
using System.Collections;

[ExecuteInEditMode, RequireComponent(typeof (MeshFilter), typeof (MeshRenderer))]
public class Triangle : MonoBehaviour
{
    [SerializeField] private Vector3 normal = Vector3.back;
    [SerializeField] private Vector3[] points = new Vector3[3];

    private Mesh mesh;
    private Vector3[] vertices;
    private int[] triangles;
    private Color[] colors;
    private Vector3[] normals;

    private void OnEnable()
    {
        UpdateMesh();
    }

    private void OnDisable()
    {
        if (Application.isEditor)
        {
            GetComponent<MeshFilter>().mesh = null;
            DestroyImmediate(mesh);
        }
    }

    private void Reset()
    {
        UpdateMesh();
    }

    public void UpdateMesh()
    {
        mesh = new Mesh();
        mesh.name = "Generated Triangle Mesh";
        mesh.hideFlags = HideFlags.HideAndDontSave;

        vertices = new Vector3[points.Length + 1];
        colors = new Color[vertices.Length];
        normals = new Vector3[vertices.Length];
        triangles = new int[points.Length * 3];

        for (var i = 0; i < vertices.Length; i++)
        {
            colors[i] = Color.white;
            normals[i] = transform.TransformDirection(normal);
        }

        var center = new Vector3();
        center = points.Aggregate(center, (current, point) => current + point) / points.Length;
        vertices[0] = center;

        for (int v = 1, t = 1; v < vertices.Length; v++, t += 3)
        {
            vertices[v] = points[v - 1];
            triangles[t] = v;
            triangles[t + 1] = v + 1;
            
        }
        triangles[triangles.Length - 1] = 1;

        mesh.vertices = vertices;
        mesh.triangles = triangles;
        mesh.uv = new Vector2[vertices.Length];
        mesh.colors = colors;
        mesh.normals = normals;

        var meshFilter = GetComponent<MeshFilter>();
        if (meshFilter != null)
            meshFilter.mesh = mesh;

        var meshCollider = GetComponent<MeshCollider>();
        if (meshCollider != null)
            meshCollider.sharedMesh = mesh;
    }
}
