﻿using System.Collections;
using UnityEngine;

public class TimeBase : MonoBehaviourBase
{
    [SerializeField] private float timeScale = 1f;

    public float TimeScale
    {
        get { return timeScale; }
        set { timeScale = value; }
    }

    public bool Paused { get { return timeScale == 0; } }

    public float DeltaTime { get { return Time.deltaTime * timeScale; } }
    public float SmoothDeltaTime { get { return Time.smoothDeltaTime * timeScale; } }
    public float ScaledTimeSinceStartup { get; private set; }
    public float ScaledTimeSinceLevelLoad { get; private set; }

    protected virtual void OnLevelWasLoaded()
    {
        ScaledTimeSinceLevelLoad = 0;
    }

    private void Update()
    {
        ScaledTimeSinceStartup += DeltaTime;
        ScaledTimeSinceLevelLoad += DeltaTime;
    }

    public Coroutine WaitForSecondsCoroutine(float seconds)
    {
        return StartCoroutine(WaitForSecondsEnumerator(seconds));
    }

    private IEnumerator WaitForSecondsEnumerator(float seconds)
    {
        while (seconds >= 0)
        {
            yield return null;
            seconds -= DeltaTime;
        }
    }
}
