﻿using System.Collections;
using UnityEngine;

public class TimeBaseSingleton<T> : TimeBase where T : TimeBaseSingleton<T>
{
    private static T instance;
    protected bool InstanceExists { get { return instance != null; } }
    public static T Instance { get { return instance; } }

    protected virtual void Awake()
    {
        if (InstanceExists)
        {
            Destroy(gameObject);
            return;
        }

        instance = (T) this;
        DontDestroyOnLoad(gameObject);
    }
}
