﻿using UnityEditor;
using UnityEngine;

[CustomEditor(typeof (RageGlowCopyParentShape))]
public class RageGlowCopyParentShapeInspector : Editor
{
    private float previousScale;
    private float previousScaleControlPoints;
    private int previousVertexDensity;

    private RageGlowCopyParentShape Glow { get { return (RageGlowCopyParentShape) target; } }

    private SerializedProperty propertyVertexDensity;

    private void OnEnable()
    {
        propertyVertexDensity = serializedObject.FindProperty("vertexDensity");
    }

    public override void OnInspectorGUI()
    {
        serializedObject.Update();

        DrawPropertiesExcluding(serializedObject);

        GUILayout.BeginHorizontal();
        GUILayout.Label("Vertex Density:");
        if (GUILayout.Button("+"))
        {
            propertyVertexDensity.intValue++;
        }
        if (GUILayout.Button("-"))
        {
            if (propertyVertexDensity.intValue > 0)
                propertyVertexDensity.intValue--;
        }
        GUILayout.EndHorizontal();

        if (GUILayout.Button("Refresh"))
        {
            ((RageGlowCopyParentShape) target).Refresh(true);
        }

        if (serializedObject.ApplyModifiedProperties())
        {
            var refreshPoints = false;

            if (Glow.Scale != previousScale)
            {
                previousScale = Glow.Scale;
                refreshPoints = true;
            }

            if (Glow.ScaleControlPoints != previousScaleControlPoints)
            {
                previousScaleControlPoints = Glow.ScaleControlPoints;
                refreshPoints = true;
            }

            if (Glow.VertexDensity != previousVertexDensity)
            {
                previousVertexDensity = Glow.VertexDensity;
                refreshPoints = true;
            }

            Glow.Refresh(refreshPoints);
            EditorUtility.SetDirty(target);
        }
    }
}