﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using UnityEngine;

public class RageShapePolygon : AbstractRageShape
{
    [Serializable]
    public class ControlPoint
    {
        public float angle;
        public float length;
    }

    [SerializeField] private Vector3[] point = new Vector3[2];
    [SerializeField] private ControlPoint[] pointAngles;
    [SerializeField] private float controlPointDistance = 0f;
    [SerializeField] private bool pointsAreWorldPositions = false;

    public override void Refresh()
    {
        base.Refresh();

        RefreshPointCount(point.Length);

        for (int i = 0; i < point.Length; i++)
        {
            var position = point[i] * scale;
            if (pointsAreWorldPositions)
            {
                position = transform.InverseTransformPoint(position);
            }

		    var innerControlPoint = new Vector3(position.y, -position.x).normalized * controlPointDistance * scale;
            if ((pointAngles != null) && (i  < pointAngles.Length))
            {
                var controlPoint = pointAngles[i];

                while (controlPoint.angle < 0)
                {
                    controlPoint.angle += 360f;
                }

                while (controlPoint.angle >= 360f)
                {
                    controlPoint.angle -= 360f;
                }

                innerControlPoint = UnityHelper.CreateVector2AngleDeg(controlPoint.angle) * controlPoint.length * controlPointDistance * scale;
            }

		    SetNaturalPoint(i, position, innerControlPoint);
        }

        RefreshMesh();
    }

    public Vector3[] Point
    {
        get { return point; }
        set { point = value; }
    }
}
